pub fn decode_key_binding_registry(
data: &ObjectData,
) -> Result<KeyBindingRegistry>Expand description
Decode a key-binding wire object and verify its advertised content address.
pub fn decode_key_binding_registry(
data: &ObjectData,
) -> Result<KeyBindingRegistry>Decode a key-binding wire object and verify its advertised content address.