pub fn encode_section(
tag: SectionTag,
body: &[u8],
out: &mut [u8],
) -> Result<usize, EncodeError>Expand description
Encodes a single section into the provided output buffer.
pub fn encode_section(
tag: SectionTag,
body: &[u8],
out: &mut [u8],
) -> Result<usize, EncodeError>Encodes a single section into the provided output buffer.