pub fn parse_invite(url: &str) -> Result<InvitePayload>Expand description
Parse an invite URL and verify the embedded signature against the embedded card’s first active verify key.
pub fn parse_invite(url: &str) -> Result<InvitePayload>Parse an invite URL and verify the embedded signature against the embedded card’s first active verify key.