attestation_payload

Function attestation_payload 

pub fn attestation_payload(fingerprint: &[u8; 32], session_did: &str) -> String
The canonical message the operator key signs / a receiver verifies. Domain-separated; the fingerprint is lowercase hex so the message is a plain printable string on the same sign_did_cert path as the other certs.