pub fn install() -> Result<ServiceReport>Expand description
Install a user-scope service unit that runs wire daemon and writes
a P0.4 versioned pidfile.
pub fn install() -> Result<ServiceReport>Install a user-scope service unit that runs wire daemon and writes
a P0.4 versioned pidfile.