Crate wire

Crate wire 

Shared protocol/auth transport types.

Structs

AuthContext
AuthToken
Capabilities
Set of protocol capabilities.
CapabilitySet
A set of capabilities that have been negotiated.
CreateHostedGrant
CreateHostedRepository
CreateNamespace
DeleteHostedGrant
DeleteHostedRepository
DeleteNamespace
DeltaData
Delta-encoded data.
Error
HarnessIdentity
HaveObjects
HostedGrantCreated
HostedGrantDeleted
HostedGrantInfo
HostedGrantUpdated
HostedGrantsList
HostedNamespaceInfo
HostedRepositoryInfo
ListHostedGrants
ListHostedNamespaces
ListHostedRepositories
ListRefs
NamespaceCreated
NamespaceDeleted
NamespaceUpdated
NamespacesList
NativePackBundle
ObjectAvailabilityPlan
ObjectData
ObjectInfo
ObjectRequest
PackChunkState
PlannedObject
ProgressCheckpoint
PullComplete
PushComplete
RefEntry
RefFilter
RefUpdated
RefsList
RepositoriesList
RepositoryCreated
RepositoryDeleted
RepositoryUpdated
RequestDelta
Request a delta-encoded object.
SendObjects
SessionDiffSummary
SessionReportEnvelope
StateClosureOptions
Status
TranscriptAttachmentRef
UpdateHostedGrant
UpdateHostedRepository
UpdateNamespace
UpdateRef
UsageTotals
WantObjects
WorktreeChangeBaseline

Enums

AuthMethod
ErrorCode
HeadInfo
ObjectId
ObjectType
Permission
ProtocolError
Error type for protocol operations.
StatusCode
TokenScope

Constants

CAPABILITY_CHUNKED_TRANSFER
CAPABILITY_PACK_TRANSFER
CAPABILITY_PARTIAL_FETCH
CAPABILITY_RESUMABLE_TRANSFER
DEFAULT_PORT
Default port for Heddle protocol.
MAX_MESSAGE_SIZE
Maximum message size (64 MB).
MAX_PULL_DECODE_MESSAGE_SIZE
Inbound gRPC decode limit for the pull stream (tonic’s max_decoding_message_size).
MAX_RECEIVED_REDACTIONS_BLOB_SIZE
Maximum redaction sidecar blob accepted from the pull stream, per blob.
MAX_RECEIVED_STATE_VISIBILITY_BLOB_SIZE
Maximum state-visibility sidecar blob accepted from the pull stream, per state.
PROTOCOL_VERSION
Protocol version.

Functions

build_native_pack
check_received_transfer_blob_size
Reject a received per-object transfer sidecar blob whose length exceeds max_bytes, before it is handed to the repository accept path.
chunk_bounds
chunk_count
chunk_offset
enumerate_state_closure
enumerate_state_closure_plan
enumerate_state_closure_plan_with_options
enumerate_state_closure_with_options
has_object
install_received_pack
is_ancestor
is_native_packable_object_type
load_object_data
load_requested_object
native_pack_excluded_object_types
next_pack_chunk
plan_object_availability
receive_pack_chunk
scope_contains
Whether candidate is the scope namespace itself or a descendant of it, compared whole-segment by whole-segment.
store_received_object

Type Aliases

Result